@@ -1,11 +1,11 @@
-use crate::fill_harmonics::FillHarmonics;
+use crate::traits::FillHarmonics;
 use crate::{SCOPE, TONIC};
 use std::collections::HashMap;
 
 /// Note of the harmonic harmonic series N+1/N where N is 1..inf because dividing by zero is the tonic "quote me"
 /// Naming conventions in this index are according to physical position of a string to ring a given harmonic
 /// ::the indexing is the inverse of the harmonic series to make visualizing the frequency a physical location along a string
-#[derive(Debug, Clone)]
+#[derive(Default)]
 pub struct NaturalMusicBox {
     tonic: f64,
     pub harmonics: HashMap<String, f64>,
@@ -41,3 +41,4 @@ impl FillHarmonics for NaturalMusicBox {
         }
     }
 }
+
